#!/bin/sh
#
# clamav-milter	Script to start and stop the clamav-milter daemon
#
# chkconfig: - 77 23
# description: clamav-milter is a daemon which hooks into sendmail and routes
#              email messages to clamav
#
# processname: clamav-milter
# config: /etc/sysconfig/clamav-milter
# pidfile: /var/run/clamav/clamav-milter.pid
#

# Source function library
. /etc/rc.d/init.d/functions

# Get network config
. /etc/sysconfig/network

# Local clamav-milter config
test -f /etc/sysconfig/clamav-milter || exit 0
. /etc/sysconfig/clamav-milter

RETVAL=0

start() {
        echo -n $"Starting clamav-milter: "
        daemon /usr/sbin/clamav-milter $CLAMAV_FLAGS
        RETVAL=$?
        echo
	[ $RETVAL -eq 0 ] && touch /var/lock/subsys/clamav-milter
	return $RETVAL
}

stop() {
        echo -n $"Stopping clamav-milter: "
        killproc clamav-milter
        RETVAL=$?
        echo
	[ $RETVAL -eq 0 ] && rm -f /var/lock/subsys/clamav-milter
	return $RETVAL
}

restart() {
	stop
	start
}

reload() {
	echo -n $"Reloading log file: "
	killproc clamav-milter -SIGHUP
	RETVAL=$?
	echo
	return $RETVAL
}


case "$1" in
  start)
	start
        ;;
  stop)
	stop
        ;;
  status)
        status clamav-milter
        ;;
  restart)
	restart
	;;
  condrestart)
	[ -f /var/lock/subsys/clamav-milter ] && restart || :
        ;;
  reload)
	reload
	;;
  *)
        echo $"Usage: $0 {start|stop|status|restart|condrestart|reload}"
        exit 1
esac

exit $?

